==> greenbone-security-assistant_26.7.0.orig.tar.gz: gsa-26.7.0/src/web/pages/reports/details/Summary.tsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import React, {useState, useEffect} from 'react';
import styled from 'styled-components';
import {
  type Date as GmpDate,
  duration as createDuration,
} from 'gmp/models/date';
import type Filter from 'gmp/models/filter';
import type ReportReport from 'gmp/models/report/report';
import {TASK_STATUS} from 'gmp/models/task';
import {isDefined} from 'gmp/utils/identity';
import StatusBar from 'web/components/bar/StatusBar';
import DateTime from 'web/components/date/DateTime';
import ErrorPanel from 'web/components/error/ErrorPanel';
import Layout from 'web/components/layout/Layout';
import DetailsLink from 'web/components/link/DetailsLink';
import Table from 'web/components/table/InfoTable';
import TableBody from 'web/components/table/TableBody';
import TableCol from 'web/components/table/TableCol';
import TableData from 'web/components/table/TableData';
import TableRow from 'web/components/table/TableRow';
import useTranslation from 'web/hooks/useTranslation';

interface UpdatingTableProps {
  $isUpdating: boolean;
}

interface SummaryProps {
  audit?: boolean;
  filter: Filter;
  isUpdating?: boolean;
  links?: boolean;
  report: ReportReport;
  reportId: string;
  reportError?: Error;
}

const UpdatingTable = styled(Table)<UpdatingTableProps>`
  opacity: ${props => (props.$isUpdating ? '0.2' : '1.0')};
`;

const Summary = ({
  audit = false,
  filter,
  isUpdating = false,
  links = true,
  report,
  reportId,
  reportError,
}: SummaryProps) => {
  const [_] = useTranslation();
  const {
    delta_report,
    hosts,
    scan_end,
    scan_run_status,
    scan_start,
    // @ts-expect-error
    slave,
    task,
    timezone,
    timezone_abbrev,
  } = report;

  const {id, name, comment, progress} = task ?? {};

  const [hostsCount, setHostsCount] = useState(0);

  const scanDuration = (start: GmpDate, end: GmpDate) => {
    const dur = createDuration(end.diff(start));
    const hours = dur.hours();
    const days = dur.days();

    let minutes: string | number = dur.minutes();
    if (minutes < 10) {
      minutes = '0' + minutes;
    }

    if (days === 0) {
      return _('{{hours}}:{{minutes}} h', {hours, minutes});
    }

    if (days === 1) {
      return _('{{days}} day {{hours}}:{{minutes}} h', {
        days,
        hours,
        minutes,
      });
    }

    return _('{{days}} days {{hours}}:{{minutes}} h', {
      days,
      hours,
      minutes,
    });
  };

  useEffect(() => {
    if (isDefined(hosts?.counts?.all)) {
      setHostsCount(hosts.counts.all);
    }
  }, [hosts]);

  const filterString = isDefined(filter)
    ? filter.simple().toFilterString()
    : '';

  const status =
    isDefined(task?.isImport) && task.isImport()
      ? TASK_STATUS.import
      : scan_run_status;

  const delta = isDefined(report.isDeltaReport)
    ? report.isDeltaReport()
    : false;

  const isEnded = isDefined(scan_end) && scan_end.isValid();

  const reportType = audit ? 'auditreport' : 'report';

  return (
    <Layout flex="column">
      {isDefined(reportError) && (
        <ErrorPanel
          error={reportError}
          message={_('Error while loading Report {{reportId}}', {reportId})}
        />
      )}
      <UpdatingTable $isUpdating={isUpdating}>
        <colgroup>
          <TableCol width="10%" />
          <TableCol width="90%" />
        </colgroup>
        <TableBody>
          <TableRow>
            <TableData>{_('Task Name')}</TableData>
            <TableData>
              <span>
                <DetailsLink id={id as string} textOnly={!links} type="task">
                  {name}
                </DetailsLink>
              </span>
            </TableData>
          </TableRow>
          {isDefined(comment) && (
            <TableRow>
              <TableData>{_('Comment')}</TableData>
              <TableData>{comment}</TableData>
            </TableRow>
          )}
          {delta && (
            <TableRow>
              <TableData>{_('Report 1')}</TableData>
              <TableData>
                <span>
                  <DetailsLink
                    id={report.id as string}
                    textOnly={!links}
                    type={reportType}
                  >
                    {report.id}
                  </DetailsLink>
                </span>
              </TableData>
            </TableRow>
          )}
          {isDefined(scan_start) && (
            <TableRow>
              <TableData>
                {delta ? _('Scan Time Report 1') : _('Scan Time')}
              </TableData>
              <TableData flex="row">
                <DateTime date={scan_start} />
                {isEnded && (
                  <React.Fragment>
                    {' - '}
                    <DateTime date={scan_end} />
                  </React.Fragment>
                )}
              </TableData>
            </TableRow>
          )}
          {isEnded && (
            <TableRow>
              <TableData>
                {delta ? _('Scan Duration Report 1') : _('Scan Duration')}
              </TableData>
              <TableData>
                {scanDuration(scan_start as GmpDate, scan_end as GmpDate)}
              </TableData>
            </TableRow>
          )}
          <TableRow>
            <TableData>
              {delta ? _('Scan Status Report 1') : _('Scan Status')}
            </TableData>
            <TableData>
              <StatusBar progress={progress} status={status} />
            </TableData>
          </TableRow>
          {delta && (
            <TableRow>
              <TableData>{_('Report 2')}</TableData>
              <TableData>
                <span>
                  <DetailsLink
                    id={delta_report?.id as string}
                    textOnly={!links}
                    type={reportType}
                  >
                    {delta_report?.id}
                  </DetailsLink>
                </span>
              </TableData>
            </TableRow>
          )}
          {delta && (
            <TableRow>
              <TableData>{_('Scan Time Report 2')}</TableData>
              <TableData flex="row">
                <DateTime date={delta_report?.scan_start} />
                {isDefined(delta_report?.scan_end) &&
                  delta_report.scan_end.isValid() && (
                    <React.Fragment>
                      {' - '}
                      <DateTime date={delta_report.scan_end} />
                    </React.Fragment>
                  )}
              </TableData>
            </TableRow>
          )}
          {delta && delta_report?.scan_end?.isValid() && (
            <TableRow>
              <TableData>{_('Scan Duration Report 2')}</TableData>
              <TableData flex="row">
                {scanDuration(
                  delta_report?.scan_start as GmpDate,
                  delta_report.scan_end,
                )}
              </TableData>
            </TableRow>
          )}
          {delta && (
            <TableRow>
              <TableData>{_('Scan Status Report 2')}</TableData>
              <TableData>
                <StatusBar status={delta_report?.scan_run_status} />
              </TableData>
            </TableRow>
          )}
          {isDefined(slave) && (
            <TableRow>
              <TableData>{_('Scan sensor')}</TableData>
              <TableData>{slave.name}</TableData>
            </TableRow>
          )}
          {hostsCount > 0 && (
            <TableRow>
              <TableData>{_('Hosts scanned')}</TableData>
              <TableData>{hostsCount}</TableData>
            </TableRow>
          )}
          <TableRow>
            <TableData>{_('Filter')}</TableData>
            <TableData>{filterString}</TableData>
          </TableRow>
          <TableRow>
            <TableData>{_('Timezone')}</TableData>
            <TableData>
              {timezone} ({timezone_abbrev})
            </TableData>
          </TableRow>
        </TableBody>
      </UpdatingTable>
    </Layout>
  );
};

export default Summary;

==> greenbone-security-assistant_26.8.0.orig.tar.gz: gsa-26.8.0/src/web/pages/reports/details/Summary.tsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import React, {useState, useEffect} from 'react';
import styled from 'styled-components';
import {
  type Date as GmpDate,
  duration as createDuration,
} from 'gmp/models/date';
import type Filter from 'gmp/models/filter';
import type ReportReport from 'gmp/models/report/report';
import {TASK_STATUS} from 'gmp/models/task';
import {isDefined} from 'gmp/utils/identity';
import StatusBar from 'web/components/bar/StatusBar';
import DateTime from 'web/components/date/DateTime';
import ErrorPanel from 'web/components/error/ErrorPanel';
import Layout from 'web/components/layout/Layout';
import DetailsLink from 'web/components/link/DetailsLink';
import Table from 'web/components/table/InfoTable';
import TableBody from 'web/components/table/TableBody';
import TableCol from 'web/components/table/TableCol';
import TableData from 'web/components/table/TableData';
import TableRow from 'web/components/table/TableRow';
import useTranslation from 'web/hooks/useTranslation';

interface UpdatingTableProps {
  $isUpdating: boolean;
}

interface SummaryProps {
  audit?: boolean;
  filter: Filter;
  isUpdating?: boolean;
  links?: boolean;
  report: ReportReport;
  reportId: string;
  reportError?: Error;
}

const UpdatingTable = styled(Table)<UpdatingTableProps>`
  opacity: ${props => (props.$isUpdating ? '0.2' : '1.0')};
`;

const Summary = ({
  audit = false,
  filter,
  isUpdating = false,
  links = true,
  report,
  reportId,
  reportError,
}: SummaryProps) => {
  const [_] = useTranslation();
  const {
    delta_report,
    hosts,
    scan_end,
    scan_run_status,
    scan_start,
    // @ts-expect-error
    slave,
    task,
    timezone,
    timezone_abbrev,
  } = report;

  const {id, name, comment, progress} = task ?? {};

  const [hostsCount, setHostsCount] = useState(0);

  const scanDuration = (start: GmpDate, end: GmpDate) => {
    const dur = createDuration(end.diff(start));
    const hours = dur.hours();
    const days = dur.days();

    let minutes: string | number = dur.minutes();
    if (minutes < 10) {
      minutes = '0' + minutes;
    }

    if (days === 0) {
      return _('{{hours}}:{{minutes}} h', {hours, minutes});
    }

    if (days === 1) {
      return _('{{days}} day {{hours}}:{{minutes}} h', {
        days,
        hours,
        minutes,
      });
    }

    return _('{{days}} days {{hours}}:{{minutes}} h', {
      days,
      hours,
      minutes,
    });
  };

  useEffect(() => {
    if (isDefined(hosts?.counts?.all)) {
      setHostsCount(hosts.counts.all);
    }
  }, [hosts]);

  const filterString = isDefined(filter)
    ? filter.simple().toFilterString()
    : '';

  const status =
    isDefined(task?.isImport) && task.isImport()
      ? TASK_STATUS.import
      : scan_run_status;

  const delta = isDefined(report.isDeltaReport)
    ? report.isDeltaReport()
    : false;

  const isEnded = isDefined(scan_end) && scan_end.isValid();

  const reportType = audit ? 'auditreport' : 'report';
  const linkType = audit ? 'audit' : 'task';

  return (
    <Layout flex="column">
      {isDefined(reportError) && (
        <ErrorPanel
          error={reportError}
          message={_('Error while loading Report {{reportId}}', {reportId})}
        />
      )}
      <UpdatingTable $isUpdating={isUpdating}>
        <colgroup>
          <TableCol width="10%" />
          <TableCol width="90%" />
        </colgroup>
        <TableBody>
          <TableRow>
            <TableData>{_('Task Name')}</TableData>
            <TableData>
              <span>
                <DetailsLink
                  id={id as string}
                  textOnly={!links}
                  type={linkType}
                >
                  {name}
                </DetailsLink>
              </span>
            </TableData>
          </TableRow>
          {isDefined(comment) && (
            <TableRow>
              <TableData>{_('Comment')}</TableData>
              <TableData>{comment}</TableData>
            </TableRow>
          )}
          {delta && (
            <TableRow>
              <TableData>{_('Report 1')}</TableData>
              <TableData>
                <span>
                  <DetailsLink
                    id={report.id as string}
                    textOnly={!links}
                    type={reportType}
                  >
                    {report.id}
                  </DetailsLink>
                </span>
              </TableData>
            </TableRow>
          )}
          {isDefined(scan_start) && (
            <TableRow>
              <TableData>
                {delta ? _('Scan Time Report 1') : _('Scan Time')}
              </TableData>
              <TableData flex="row">
                <DateTime date={scan_start} />
                {isEnded && (
                  <React.Fragment>
                    {' - '}
                    <DateTime date={scan_end} />
                  </React.Fragment>
                )}
              </TableData>
            </TableRow>
          )}
          {isEnded && (
            <TableRow>
              <TableData>
                {delta ? _('Scan Duration Report 1') : _('Scan Duration')}
              </TableData>
              <TableData>
                {scanDuration(scan_start as GmpDate, scan_end as GmpDate)}
              </TableData>
            </TableRow>
          )}
          <TableRow>
            <TableData>
              {delta ? _('Scan Status Report 1') : _('Scan Status')}
            </TableData>
            <TableData>
              <StatusBar progress={progress} status={status} />
            </TableData>
          </TableRow>
          {delta && (
            <TableRow>
              <TableData>{_('Report 2')}</TableData>
              <TableData>
                <span>
                  <DetailsLink
                    id={delta_report?.id as string}
                    textOnly={!links}
                    type={reportType}
                  >
                    {delta_report?.id}
                  </DetailsLink>
                </span>
              </TableData>
            </TableRow>
          )}
          {delta && (
            <TableRow>
              <TableData>{_('Scan Time Report 2')}</TableData>
              <TableData flex="row">
                <DateTime date={delta_report?.scan_start} />
                {isDefined(delta_report?.scan_end) &&
                  delta_report.scan_end.isValid() && (
                    <React.Fragment>
                      {' - '}
                      <DateTime date={delta_report.scan_end} />
                    </React.Fragment>
                  )}
              </TableData>
            </TableRow>
          )}
          {delta && delta_report?.scan_end?.isValid() && (
            <TableRow>
              <TableData>{_('Scan Duration Report 2')}</TableData>
              <TableData flex="row">
                {scanDuration(
                  delta_report?.scan_start as GmpDate,
                  delta_report.scan_end,
                )}
              </TableData>
            </TableRow>
          )}
          {delta && (
            <TableRow>
              <TableData>{_('Scan Status Report 2')}</TableData>
              <TableData>
                <StatusBar status={delta_report?.scan_run_status} />
              </TableData>
            </TableRow>
          )}
          {isDefined(slave) && (
            <TableRow>
              <TableData>{_('Scan sensor')}</TableData>
              <TableData>{slave.name}</TableData>
            </TableRow>
          )}
          {hostsCount > 0 && (
            <TableRow>
              <TableData>{_('Hosts scanned')}</TableData>
              <TableData>{hostsCount}</TableData>
            </TableRow>
          )}
          <TableRow>
            <TableData>{_('Filter')}</TableData>
            <TableData>{filterString}</TableData>
          </TableRow>
          <TableRow>
            <TableData>{_('Timezone')}</TableData>
            <TableData>
              {timezone} ({timezone_abbrev})
            </TableData>
          </TableRow>
        </TableBody>
      </UpdatingTable>
    </Layout>
  );
};

export default Summary;
